import { ControlValueAccessor } from '@angular/forms';
import { Button } from './button.model';
/**
 * An Angular 6 Bootstrap 3 Button Group Component
 * @example
 * <nbbg-button-group [buttons]="buttons" [vertical]="vertical" [justified]="justified" [disabled]="disabled" [(ngModel)]="selectedButton"></nbbg-button-group>
 */
export declare class ButtonGroupComponent implements ControlValueAccessor {
    /**
     * List of buttons in this group
     */
    buttons: Button[];
    /**
     * Value of the selected button
     */
    selectedButtonValue: string;
    /**
     * If true then buttons appears vertically stacked
     */
    vertical: boolean;
    /**
     * If true makes the buttons stretch at equal sizes to span the entire width of its parent
     */
    justified: boolean;
    /**
     * Disables buttons
     */
    disabled: boolean;
    /**
     * Function to call back when button is clicked
     */
    _onChange: (value: string) => void;
    constructor();
    /**
     * Called when a button is clicked
     * @param value Value of the selected button
     */
    onClick(value: string): void;
    writeValue(value: string): void;
    registerOnChange(fn: (value: string) => void): void;
    registerOnTouched(): void;
}
